// Объявление параметров конфигурации трейдера.
var config =
{
  // Торгуемый инструмент - фьючерс на акции Сбербанка.
  security : "MCXF.SBRF",
  // Рабочий интервал - 1 час.
  timeframe : Timeframe.H1,
  // Количество торгуемых лотов - 1.
  quantity : 1
}

// Объявление набора локальных переменных для хранения состояния трейдера.
// Признак того, что появилась новая свеча.
var candle_changed = false;

// Функция init() вызывается при старте трейдера.
function init()
{
  // Инициализируем объект singleStockTrader.
  singleStockTrader.init(config.security, config.quantity, config.timeframe, 3);
}

function onTick(tick)
{
  // Если данный тик привел к смене бара, запоминаем это событие. В случае, если будет открыт ордер,
  // эту переменную нужно будет сбросить, чтобы закрытие ордера не могло произойти, пока бар не сменится.
  if(singleStockTrader.candle_series.is_new_bar)
    candle_changed = true;
  var position = singleStockTrader.position();
  // Если трейдер в кеше, проверяем условия для входа в позицию.
  if(position == TraderPosition.CASH)
  {
    // Получаем предыдущую свечу (индекс 1)
    var prev_candle = singleStockTrader.candle_series.getCandle(1);
    if(prev_candle.isNull())
    {
      // Предыдущей свечи нет, значит candle_series еще не заполнен, выходим.
      return;
    }
    // Если текущая цена выше максимума предыдущей свечи, входим в лонг.
    if(tick.price > prev_candle.high)
    {
      if(singleStockTrader.openOrder(OrderOperation.BUY))
        candle_changed = false;
    }
    // Иначе, если текущая цена ниже минимума предыдущей свечи, входим в шорт.
    else if(tick.price < prev_candle.low)
    {
      if(singleStockTrader.openOrder(OrderOperation.SELL))
        candle_changed = false;
    }
  }
  // Иначе, если трейдер в позиции, проверяем условия для выхода из позиции.
  // Выходить из позиции мы можем только после смены бара.
  else if(candle_changed)
  {
    // Получаем свечу, которая была до предыдущей (индекс 2)
    var prev_candle = singleStockTrader.candle_series.getCandle(2);
    if(prev_candle.isNull())
    {
      // Свечи еще нет, выходим.
      return;
    }

    // Если мы в лонге и текущая цена меньше минимума пред-предыдущей свечи, закрываем ордер.
    if(position == TraderPosition.LONG && tick.price < prev_candle.low)
      singleStockTrader.closeOrder();
    // Если мы в шорте и текущая цена больше максимума пред-предыдущей свечи, закрываем ордер.
    else if(trader.position == TraderPosition.SHORT && tick.price > prev_candle.high)
      singleStockTrader.closeOrder();
  }
}
